<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 13, 2020
 */

/**
 * Acronis backups api.
 *
 * @package Interworx
 * @subpackage Plugin
 */
class Model_RecoveryPlan_Api extends Model_Api
{
    /**
     * @param string $planId
     * @return Model_ApiResponse_Task
     */
    public function getTaskByPlanId($planId)
    {
        // todo - check progress other endpoint
        $apiEndpoint = '/bc/api/task_manager/v2/tasks?policyId=' . strtolower($planId) . '&policyId=' . strtoupper($planId);
        $res = $this->_getCookieClient()->sendAuthenticatedGetRequest($apiEndpoint);
        $task = $res[0];

        if (empty($task)) {
            throw new Exception_Acronis_InvalidInput($planId);
        }

        return new Model_ApiResponse_Task($task);
    }

    /**
     * Resume recovery if paused due to recovery error.
     *
     * @param string $uuid
     */
    public function ignoreErrorsAndResumeRecovery($uuid)
    {
        $agent_id = $this->_getAgentId();
        $query = http_build_query(array(
            'machineId' => $agent_id
        ));

        $endpoint = "/bc/api/ams/activities/$uuid?$query";

        $config = array(
            'data' => array(
                'machineId' => $agent_id,
                'action' => 'resume',
                'actionId' => 'ignore'
            )
        );

        $this->_getCookieClient()->sendAuthenticatedPostRequest($endpoint, $config);
    }


    /**
     * Get all tasks (recoveries / backups)
     *
     * @return array
     */
    public function getAllTasks()
    {
        $instance_id = $this->_getInstanceId();
        $endpoint = "/bc/api/task_manager/v2/tasks?limit=20&order=desc(enqueuedAt)&resourceId=$instance_id&resourceId=$instance_id";

        return $this->_getCookieClient()->sendAuthenticatedGetRequest($endpoint);
    }
}
